@@ -2,6 +2,7 @@ import json
 import sys
 import random
 import requests
+import time
 
 class Singleton(type):
     _instances = {}
@@ -21,20 +22,20 @@ class Slack(metaclass=Singleton):
         url = self.web_hook
         message = message
         title = title
+        ts = time.time()
         slack_data = {
             "username": "NotificationBot",
             "icon_emoji": ":satellite:",
             "channel" : "#integration-alerts",
+            "author_icon": "https://www.youorder.me/assets/icons/ic_logo_footer.svg",
             "attachments": [
                 {
                     "color": "#9733EE",
-                    "fields": [
-                        {
-                            "title": title,
-                            "value": message,
-                            "short": "false",
-                        }
-                    ]
+                    "title": title,
+                    "text": message,
+                    "footer": "Integrations YOM",
+                    "footer_icon": "https://www.youorder.me/assets/icons/ic_logo_footer.svg"
+                    "ts": ts,
                 }
             ]
         }
